==> commons-model-4.2.0-sources.jar: com/epam/ta/reportportal/ws/model/ValidationConstraints.java <==
/*
 * Copyright 2016 EPAM Systems
 * 
 * 
 * This file is part of EPAM Report Portal.
 * https://github.com/reportportal/commons-model
 * 
 * Report Portal is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Report Portal is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with Report Portal.  If not, see <http://www.gnu.org/licenses/>.
 */

package com.epam.ta.reportportal.ws.model;

/**
 * Contains constants for defining validation constraints.
 *
 * @author Aliaksei_Makayed
 */
//TODO review and move to API service
public class ValidationConstraints {

	private ValidationConstraints() {

	}

	/* 1 always exists as predefined type */
	public static final int MAX_ISSUE_SUBTYPES = 11;

	public static final int MIN_COLLECTION_SIZE = 1;
	public static final int MAX_NUMBER_OF_FILTER_ENTITIES = 20;
	public static final int MIN_WIDGET_LIMIT = 1;
	public static final int MAX_WIDGET_LIMIT = 150;
	public static final int MIN_FILTER_LIMIT = 1;
	public static final int MAX_FILTER_LIMIT = 150;
	public static final int MIN_LAUNCH_NAME_LENGTH = 1;
	public static final int MIN_NAME_LENGTH = 3;
	public static final int MAX_NAME_LENGTH = 256;
	public static final int MIN_DESCRIPTION_LENGTH = 0;
	public static final int MAX_DESCRIPTION_LENGTH = 65536;
	public static final int MAX_PARAMETERS_LENGTH = 256;
	public static final int MAX_LAUNCH_DESCRIPTION_LENGTH = 1024;

	public static final int MAX_WIDGET_NAME_LENGTH = 128;
	public static final int MAX_DASHBOARD_NAME_LENGTH = 128;
	public static final int MAX_USER_FILTER_NAME_LENGTH = 128;

	public static final int MIN_PAGE_NUMBER = 1;
	public static final int MAX_PAGE_NUMBER = 1024;
	public static final int MAX_HISTORY_DEPTH_BOUND = 31;
	public static final int MIN_HISTORY_DEPTH_BOUND = 0;
	public static final int MAX_HISTORY_SIZE_BOUND = 31;

	public static final int MIN_LOGIN_LENGTH = 1;
	public static final int MAX_LOGIN_LENGTH = 128;

	public static final int MIN_PASSWORD_LENGTH = 4;
	public static final int MAX_PASSWORD_LENGTH = 25;

	public static final int TICKET_MIN_LOG_SIZE = 0;
	public static final int TICKET_MAX_LOG_SIZE = 50;

	public static final int MAX_CUSTOMER_LENGTH = 64;

	public static final int MIN_USER_NAME_LENGTH = 3;
	public static final int MAX_USER_NAME_LENGTH = 256;

	public static final int MAX_PHOTO_SIZE = 1024 * 1024;
	public static final int MAX_PHOTO_HEIGHT = 500;
	public static final int MAX_PHOTO_WIDTH = 300;

	public static final int MIN_DOMAIN_SIZE = 1;
	public static final int MAX_DOMAIN_SIZE = 255;

	public static final int MIN_SUBTYPE_SHORT_NAME = 1;
	public static final int MAX_SUBTYPE_SHORT_NAME = 4;

	public static final int MIN_SUBTYPE_LONG_NAME = 3;
	public static final int MAX_SUBTYPE_LONG_NAME = 55;

	public static final int MAX_FILTER_DESCRIPTION = 256;
	public static final int MIN_FILTER_DESCRIPTION = 1;

	public static final int MIN_DOC_FREQ = 1;
	public static final int MAX_DOC_FREQ = 10;
	public static final int MIN_TERM_FREQ = 1;
	public static final int MAX_TERM_FREQ = 10;
	public static final int MIN_SHOULD_MATCH = 50;
	public static final int MAX_SHOULD_MATCH = 100;
	public static final int MIN_NUMBER_OF_LOG_LINES = -1;
	public static final int MAX_NUMBER_OF_LOG_LINES = 5;

}

==> commons-model-5.0.0-sources.jar: com/epam/ta/reportportal/ws/model/ValidationConstraints.java <==
/*
 * Copyright 2019 EPAM Systems
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.epam.ta.reportportal.ws.model;

/**
 * Contains constants for defining validation constraints.
 *
 * @author Aliaksei_Makayed
 */
//TODO review and move to API service
public class ValidationConstraints {

	/* 1 always exists as predefined type */
	public static final int MAX_ISSUE_SUBTYPES = 15;
	public static final int MIN_COLLECTION_SIZE = 1;
	public static final int MAX_NUMBER_OF_FILTER_ENTITIES = 20;
	public static final int MIN_WIDGET_LIMIT = 1;
	public static final int MAX_WIDGET_LIMIT = 600;
	public static final int MIN_FILTER_LIMIT = 1;
	public static final int MAX_FILTER_LIMIT = 150;
	public static final int MIN_LAUNCH_NAME_LENGTH = 1;
	public static final int MAX_LAUNCH_NAME_LENGTH = 256;
	public static final int MIN_TEST_ITEM_NAME_LENGTH = 1;
	public static final int MAX_TEST_ITEM_NAME_LENGTH = 1024;
	public static final int MAX_TEST_ITEM_UNIQUE_ID_LENGTH = 1024;
	public static final int MIN_ITEM_ATTRIBUTE_VALUE_LENGTH = 1;
	public static final int MIN_NAME_LENGTH = 3;
	public static final int MAX_NAME_LENGTH = 256;
	public static final int MIN_DESCRIPTION_LENGTH = 0;
	public static final int MAX_DESCRIPTION_LENGTH = 65536;
	public static final int MAX_PARAMETERS_LENGTH = 256;
	public static final int MAX_LAUNCH_DESCRIPTION_LENGTH = 1024;
	public static final int MAX_WIDGET_NAME_LENGTH = 128;
	public static final int MAX_DASHBOARD_NAME_LENGTH = 128;
	public static final int MAX_USER_FILTER_NAME_LENGTH = 128;
	public static final int MAX_ATTRIBUTE_LENGTH = 128;
	public static final int MIN_PAGE_NUMBER = 1;
	public static final int MAX_PAGE_NUMBER = 1024;
	public static final int MAX_HISTORY_DEPTH_BOUND = 31;
	public static final int MIN_HISTORY_DEPTH_BOUND = 0;
	public static final int MAX_HISTORY_SIZE_BOUND = 31;
	public static final int MIN_LOGIN_LENGTH = 1;
	public static final int MAX_LOGIN_LENGTH = 128;
	public static final int MIN_PASSWORD_LENGTH = 4;
	public static final int MAX_PASSWORD_LENGTH = 256;
	public static final int TICKET_MIN_LOG_SIZE = 0;
	public static final int TICKET_MAX_LOG_SIZE = 50;
	public static final int MAX_CUSTOMER_LENGTH = 64;
	public static final int MIN_USER_NAME_LENGTH = 3;
	public static final int MAX_USER_NAME_LENGTH = 256;
	public static final int MAX_PHOTO_SIZE = 1024 * 1024;
	public static final int MAX_PHOTO_HEIGHT = 500;
	public static final int MAX_PHOTO_WIDTH = 300;
	public static final int MIN_DOMAIN_SIZE = 1;
	public static final int MAX_DOMAIN_SIZE = 255;
	public static final int MIN_SUBTYPE_SHORT_NAME = 1;
	public static final int MAX_SUBTYPE_SHORT_NAME = 4;
	public static final int MIN_SUBTYPE_LONG_NAME = 3;
	public static final int MAX_SUBTYPE_LONG_NAME = 55;
	public static final int MIN_ANALYSIS_PATTERN_NAME_LENGTH = 1;
	public static final int MAX_ANALYSIS_PATTERN_NAME_LENGTH = 55;
	public static final int MAX_DESCRIPTION = 256;
	public static final int MIN_DESCRIPTION = 1;
	public static final int MIN_DOC_FREQ = 1;
	public static final int MAX_DOC_FREQ = 10;
	public static final int MIN_TERM_FREQ = 1;
	public static final int MAX_TERM_FREQ = 10;
	public static final int MIN_SHOULD_MATCH = 50;
	public static final int MAX_SHOULD_MATCH = 100;
	public static final int MIN_NUMBER_OF_LOG_LINES = -1;
	public static final int MAX_NUMBER_OF_LOG_LINES = 5;
	public static final String HEX_COLOR_REGEXP = "#([A-Fa-f0-9]{6}|[A-Fa-f0-9]{3})$";
	public static final String PROJECT_NAME_REGEXP = "[a-zA-Z0-9-_]+";
	private ValidationConstraints() {

	}

}
